@@ -1,17 +1,10 @@
 package Kephra::App::EditPanel::Margin;
-our $VERSION = '0.12';
-
-=head1 NAME
-
-Kephra::App::EditPanel::Margin - managing margin visuals for marker, linenumber, folding & extra space
-
-=head1 DESCRIPTION
-
-=cut
+our $VERSION = '0.13';
 
 use strict;
 use warnings;
 
+my $mouse_y_pos;
 sub _ep_ref {
 	Kephra::App::EditPanel::is($_[0]) ? $_[0] : Kephra::App::EditPanel::_ref()   
 }
@@ -60,9 +53,9 @@ sub apply_settings_here {# eval view settings for the margin of this edit panel
 		$ep->MarkerDefine(&Wx::wxSTC_MARKNUM_FOLDEREND,    &Wx::wxSTC_MARK_ARROW,    $b,$f);
 		$ep->MarkerDefine(&Wx::wxSTC_MARKNUM_FOLDEROPEN,   &Wx::wxSTC_MARK_ARROWDOWN,$b,$f);
 		$ep->MarkerDefine(&Wx::wxSTC_MARKNUM_FOLDEROPENMID,&Wx::wxSTC_MARK_ARROWDOWN,$b,$f);
-		$ep->MarkerDefine(&Wx::wxSTC_MARKNUM_FOLDERSUB,    &Wx::wxSTC_MARK_EMPTY,    $b,$f);
 		$ep->MarkerDefine(&Wx::wxSTC_MARKNUM_FOLDERMIDTAIL,&Wx::wxSTC_MARK_EMPTY,    $b,$f);
 		$ep->MarkerDefine(&Wx::wxSTC_MARKNUM_FOLDERTAIL,   &Wx::wxSTC_MARK_EMPTY,    $b,$f);
+		$ep->MarkerDefine(&Wx::wxSTC_MARKNUM_FOLDERSUB,    &Wx::wxSTC_MARK_EMPTY,    $b,$f);
 	}
 	else {
 		$ep->MarkerDefine(&Wx::wxSTC_MARKNUM_FOLDER,       &Wx::wxSTC_MARK_BOXPLUS,  $b,$f);
@@ -87,6 +80,8 @@ sub refresh_changeable_settings {
 	apply_line_number_color_here($ep);
 	apply_fold_flag_color_here($ep);
 }
+sub get_contextmenu_visibility    { _edit_config()->{contextmenu}{margin} }
+sub switch_contextmenu_visibility { _edit_config()->{contextmenu}{margin} ^= 1 }
 #
 # deciding what to do when clicked on edit panel margin
 #
@@ -107,19 +102,34 @@ sub on_middle_click {
 sub on_right_click {
 	my ($ep, $event, $nr) = @_;
 	my ($x, $y) = ($event->GetX, $event->GetY);
-	#Kephra::Document::Data::set_value('mouse_y', $event->GetPosition->y());
-
-	if ($nr < 2){
-		$ep->PopupMenu( Kephra::App::ContextMenu::get('marker_margin'), $x, $y);
+	if ($nr > -1 and $nr < 2 and get_contextmenu_visibility() ){
+		$mouse_y_pos = $event->GetY;
+		$ep->PopupMenu( 
+			Kephra::App::ContextMenu::get( 
+				_edit_config()->{contextmenu}{ID_margin} ), $x, $y);
+		undef $mouse_y_pos;
 	}
 	elsif ($nr == 2) {
 		$event->LeftIsDown
 			? Kephra::App::EditPanel::Fold::toggle_all()
-			: Kephra::App::EditPanel::Fold::toggle_siblings($ep, $event);
+			: Kephra::App::EditPanel::Fold::toggle_level($ep, $event);
 	}
-	#Kephra::Document::Data::del_value('mouse_y');
 }
 
+sub clicked_on_line {
+	my $event = shift;
+	return -1 unless defined $mouse_y_pos or ref $event eq 'Wx::MouseEvent';
+	my $ep = _ep_ref();
+	my $x = width($ep) + 5;
+	# $mouse_y_pos is saved position where context menu poped so we can fold there
+	my $y = defined $mouse_y_pos ? $mouse_y_pos : $event->GetY;
+	my $max_y = $ep->GetSize->GetHeight;
+	my $pos = $ep->PositionFromPointClose($x, $y);
+	while ($pos < 0 and $y+10 < $max_y) {
+		$pos = $ep->PositionFromPointClose($x, $y += 10);
+	}
+	return $ep->LineFromPosition($pos);
+}
 
 
 #
@@ -254,3 +264,11 @@ sub apply_text_width_here {
 1;
 #wxSTC_MARK_MINUS wxSTC_MARK_PLUS wxSTC_MARK_CIRCLE wxSTC_MARK_SHORTARROW
 #wxSTC_FOLDFLAG_LINEBEFORE_CONTRACTED
+
+=head1 NAME
+
+Kephra::App::EditPanel::Margin - managing margin visuals for marker, linenumber, folding & extra space
+
+=head1 DESCRIPTION
+
+=cut
\ No newline at end of file
